module.exports = defineTest({
	description: 'use the original class name instead of renderName in class body'
});
